@@ -1,5 +1,5 @@
-import click
 from tabulate import tabulate
+import yaml
 
 
 def pretty_table(data: list, headers: list = None, tablefmt: str = 'github') -> str:
@@ -11,6 +11,6 @@ def pretty_table(data: list, headers: list = None, tablefmt: str = 'github') ->
     return table
 
 
-def success_echo(message: str):
-    click.secho('Success: ', nl=False, fg='green', bold=True)
-    click.echo(message)
+def pretty_info(data: dict) -> str:
+    """Print data in a nice form"""
+    return yaml.safe_dump(data)
