@@ -2,7 +2,8 @@ import click
 from ecsclient.common.exceptions import ECSClientException
 
 from .._util.exceptions import EcsmgmtClickException
-from .._util.format import success_echo, pretty_table
+from .._util.format import pretty_table
+from .._util.echo import success
 
 
 @click.command()
@@ -26,6 +27,6 @@ def cli(obj, user_id, namespace, expiry_time, secret_key):
         if expiry_time is not None:
             res = client.secret_key.get(user_id=user_id, namespace=namespace)
             msg += f'\nOld secret key "{res["secret_key_1"]}" expires at "{res["key_expiry_timestamp_1"]}".'
-        success_echo(f'Created secret key for user "{user_id}" in namespace "{namespace}":\n{msg}')
+        success(f'Created secret key for user "{user_id}" in namespace "{namespace}":\n{msg}')
     except ECSClientException as e:
         raise EcsmgmtClickException(e.message)
