@@ -2,7 +2,8 @@ import datetime
 
 import click
 
-from .._util.format import success_echo, pretty_table
+from .._util.format import pretty_table
+from .._util.echo import success
 
 
 @click.command()
@@ -29,6 +30,6 @@ def cli(obj, user_id, namespace):
             ])
     msg = pretty_table(data, tablefmt='plain')
     if data:
-        success_echo(f'Secret keys for user "{user_id}" in namespace "{namespace}":\n{msg}')
+        success(f'Secret keys for user "{user_id}" in namespace "{namespace}":\n{msg}')
     else:
         click.echo(f'User "{user_id}" in namespace "{namespace}" has no secret keys.')
