@@ -2,7 +2,7 @@ import click
 from ecsclient.common.exceptions import ECSClientException
 
 from .._util.exceptions import EcsmgmtClickException
-from .._util.format import success_echo
+from .._util.echo import success
 
 
 @click.command()
@@ -27,6 +27,6 @@ def cli(obj, user_id, namespace, tags):
 
     try:
         client.object_user.create(user_id=user_id, namespace=namespace, tags=sane_tags)
-        success_echo(f'created user "{user_id}" in namespace "{namespace}"')
+        success(f'created user "{user_id}" in namespace "{namespace}"')
     except ECSClientException as e:
         raise EcsmgmtClickException(e.message)
