@@ -2,7 +2,7 @@ import click
 from ecsclient.common.exceptions import ECSClientException
 
 from .._util.exceptions import EcsmgmtClickException
-from .._util.format import success_echo
+from .._util.echo import success
 
 
 @click.command()
@@ -16,6 +16,6 @@ def cli(obj, user_id, namespace):
 
     try:
         client.object_user.delete(user_id=user_id, namespace=namespace)
-        success_echo(f'deleted user "{user_id}" in namespace "{namespace}"')
+        success(f'deleted user "{user_id}" in namespace "{namespace}"')
     except ECSClientException as e:
         raise EcsmgmtClickException(e.message)
