@@ -1,6 +1,6 @@
 import click
 
-from .._util.format import pretty_table
+from .._util.format import pretty_info
 
 
 @click.command()
@@ -13,6 +13,6 @@ def cli(obj, user_id, namespace):
     client = obj['client']
 
     res = client.object_user.get(user_id=user_id, namespace=namespace)
-    lines = [(key, val) for key, val in res.items()]
-    msg = pretty_table(lines, tablefmt='plain')
-    click.echo(msg)
+
+    click.secho(f'User "{user_id}" info:', bold=True)
+    click.echo(pretty_info(res))
